@@ -19,8 +19,9 @@ NumericVector compute_vec_1_frac(IntegerVector vector_1,
 #include <Rcpp.h>
 using namespace Rcpp;
 
-double rms_stat(NumericVector vec_1_frac,
-         NumericVector vec_2_frac);
+double rms_stat(int draws,
+                NumericVector vec_1_frac,
+                NumericVector vec_2_frac);
 
 #endif
 
@@ -60,3 +61,28 @@ double g2_stat(int draws,
 
 #endif
 
+
+#ifndef FT_STAT_H
+#define FT_STAT_H
+
+#include <Rcpp.h>
+using namespace Rcpp;
+
+double ft_stat(int draws,
+               NumericVector vec_1_frac,
+               NumericVector vec_2_frac);
+
+#endif
+
+#ifndef CVM_STAT_H
+#define CVM_STAT_H
+
+#include <Rcpp.h>
+using namespace Rcpp;
+
+double cvm_stat(int draws,
+               NumericVector vec_1_frac,
+               NumericVector vec_2_frac);
+
+#endif
+
