@@ -2,20 +2,19 @@
 #include "discretefit.h"
 using namespace Rcpp;
 
-double rms_stat(NumericVector vec_1_frac,
+double rms_stat(int draws,
+                NumericVector vec_1_frac,
                 NumericVector vec_2_frac)  {
 
-  NumericVector x = pow((vec_1_frac - vec_2_frac), 2);
+  NumericVector x = pow((sqrt(draws) * (vec_1_frac - vec_2_frac)), 2);
 
   // Taking the sum of x
-  double y = 0;
+  double rms = 0;
 
   for(int i = 0; i < x.size(); i++){
-    y += x[i];
+    rms += x[i];
   }
 
-  double rms = sqrt(y / vec_2_frac.size());
-
   return rms;
 }
 
@@ -81,4 +80,35 @@ double g2_stat(int draws,
 
 }
 
+double ft_stat(int draws,
+               NumericVector vec_1_frac,
+               NumericVector vec_2_frac)  {
 
+  NumericVector x = pow(sqrt(vec_1_frac) - sqrt(vec_2_frac), 2);
+
+  // Taking the sum of x
+  double y = 0;
+
+  for(int i = 0; i < x.size(); i++){
+    y += x[i];
+  }
+
+  double ft = 4 * draws * y;
+
+  return ft;
+
+}
+
+
+double cvm_stat(int draws,
+                NumericVector vec_1_frac,
+                NumericVector vec_2_frac)  {
+
+  NumericVector vec_1_cumsum = cumsum(vec_1_frac);
+  NumericVector vec_2_cumsum = cumsum(vec_2_frac);
+  NumericVector x = pow(vec_1_cumsum - vec_2_cumsum, 2) * vec_2_frac;
+
+  double cvm = sum(x) * draws;
+
+  return cvm;
+}
